# openapi-client
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The `openapi_client` package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.1.0
- Package version: 0.0.4
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python >=3.6

## Installation & Usage

This python library package is generated without supporting files like setup.py or requirements files

To be able to use it, you will need these dependencies in your own package that uses this library:

* urllib3 >= 1.25.3
* python-dateutil

## Getting Started

In your own code, to use this library to connect and interact with openapi-client,
you can run the following:

```python

import time
import openapi_client
from pprint import pprint
from openapi_client.api import default_api
from openapi_client.model.conservation_status import ConservationStatus
from openapi_client.model.defendant import Defendant
from openapi_client.model.defendant_post import DefendantPost
from openapi_client.model.http_validation_error import HTTPValidationError
from openapi_client.model.judgment import Judgment
from openapi_client.model.judgment_post import JudgmentPost
from openapi_client.model.protection_class import ProtectionClass
from openapi_client.model.source import Source
from openapi_client.model.source_category import SourceCategory
from openapi_client.model.source_post import SourcePost
from openapi_client.model.species import Species
from openapi_client.model.species_bulk_patch_result import SpeciesBulkPatchResult
# Defining the host is optional and defaults to http://localhost:8000
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "http://localhost:8000"
)



# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = default_api.DefaultApi(api_client)
    species = [
        Species(
            species="species_example",
            genus="genus_example",
            family="family_example",
            order="order_example",
            _class="_class_example",
            protection_class=ProtectionClass("I"),
            conservation_status=ConservationStatus("EX"),
        ),
    ] # [Species] | 

    try:
        # Bulk Patch Species
        api_response = api_instance.bulk_patch_species_analytics_species_patch(species)
        pprint(api_response)
    except openapi_client.ApiException as e:
        print("Exception when calling DefaultApi->bulk_patch_species_analytics_species_patch: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *http://localhost:8000*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**bulk_patch_species_analytics_species_patch**](openapi_client/docs/DefaultApi.md#bulk_patch_species_analytics_species_patch) | **PATCH** /analytics/species | Bulk Patch Species
*DefaultApi* | [**get_defendant_analytics_judgment_defendant_get**](openapi_client/docs/DefaultApi.md#get_defendant_analytics_judgment_defendant_get) | **GET** /analytics/judgment/defendant | Get Defendant
*DefaultApi* | [**get_judgment_analytics_judgment_judgment_id_get**](openapi_client/docs/DefaultApi.md#get_judgment_analytics_judgment_judgment_id_get) | **GET** /analytics/judgment/{judgment_id} | Get Judgment
*DefaultApi* | [**get_sources_analytics_judgment_source_get**](openapi_client/docs/DefaultApi.md#get_sources_analytics_judgment_source_get) | **GET** /analytics/judgment/source | Get Sources
*DefaultApi* | [**get_species_analytics_species_get**](openapi_client/docs/DefaultApi.md#get_species_analytics_species_get) | **GET** /analytics/species | Get Species
*DefaultApi* | [**post_defendant_analytics_judgment_defendant_judgment_id_post**](openapi_client/docs/DefaultApi.md#post_defendant_analytics_judgment_defendant_judgment_id_post) | **POST** /analytics/judgment/defendant/{judgment_id} | Post Defendant
*DefaultApi* | [**post_judgment_analytics_judgment_post**](openapi_client/docs/DefaultApi.md#post_judgment_analytics_judgment_post) | **POST** /analytics/judgment | Post Judgment
*DefaultApi* | [**post_source_analytics_judgment_source_judgment_id_post**](openapi_client/docs/DefaultApi.md#post_source_analytics_judgment_source_judgment_id_post) | **POST** /analytics/judgment/source/{judgment_id} | Post Source
*DefaultApi* | [**read_root_get**](openapi_client/docs/DefaultApi.md#read_root_get) | **GET** / | Read Root
*DefaultApi* | [**search_judgments_analytics_judgment_get**](openapi_client/docs/DefaultApi.md#search_judgments_analytics_judgment_get) | **GET** /analytics/judgment | Search Judgments


## Documentation For Models

 - [ConservationStatus](openapi_client/docs/ConservationStatus.md)
 - [Defendant](openapi_client/docs/Defendant.md)
 - [DefendantPost](openapi_client/docs/DefendantPost.md)
 - [HTTPValidationError](openapi_client/docs/HTTPValidationError.md)
 - [Judgment](openapi_client/docs/Judgment.md)
 - [JudgmentPost](openapi_client/docs/JudgmentPost.md)
 - [ProtectionClass](openapi_client/docs/ProtectionClass.md)
 - [Source](openapi_client/docs/Source.md)
 - [SourceCategory](openapi_client/docs/SourceCategory.md)
 - [SourcePost](openapi_client/docs/SourcePost.md)
 - [Species](openapi_client/docs/Species.md)
 - [SpeciesBulkPatchResult](openapi_client/docs/SpeciesBulkPatchResult.md)
 - [SpeciesShort](openapi_client/docs/SpeciesShort.md)
 - [ValidationError](openapi_client/docs/ValidationError.md)


## Documentation For Authorization

 All endpoints do not require authorization.

## Author




## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in openapi_client.apis and openapi_client.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from openapi_client.api.default_api import DefaultApi`
- `from openapi_client.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import openapi_client
from openapi_client.apis import *
from openapi_client.models import *
```

